================================
Command-Line Interface Reference
================================

In this section you will find information on Cinder's command line utilities.

Cinder Management Commands
--------------------------

These commands are used to manage existing installations. They are designed to
be run by operators in an environment where they have direct access to the
Cinder database.

.. toctree::
   :maxdepth: 1

   cinder-manage
   cinder-status

Additional Tools and Information
--------------------------------

.. toctree::
   :maxdepth: 1

   cli-manage-volumes
   cli-set-quotas
   cli-cinder-quotas
   cli-cinder-scheduling
